hyperspy\.misc\.eds package
===========================

Submodules
----------

hyperspy\.misc\.eds\.ffast\_mac module
--------------------------------------

.. automodule:: hyperspy.misc.eds.ffast_mac
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eds\.utils module
---------------------------------

.. automodule:: hyperspy.misc.eds.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.misc.eds
    :members:
    :undoc-members:
    :show-inheritance:
